@@ -1,4 +1,4 @@
-# auto-converted from src/Scintilla.h at Thu Dec 31 15:14:01 2020
+# auto-converted from src/Scintilla.h at Sat Mar 27 12:58:57 2021
 package Win32::Mechanize::NotepadPlusPlus::Editor::Messages;
 
 use warnings;
@@ -27,6 +27,9 @@ our %scimsg_dummyhash = (
     'EDGE_LINE'                                                  => 1,
     'EDGE_MULTILINE'                                             => 3,
     'EDGE_NONE'                                                  => 0,
+    'EOLANNOTATION_BOXED'                                        => 2,
+    'EOLANNOTATION_HIDDEN'                                       => 0,
+    'EOLANNOTATION_STANDARD'                                     => 1,
     'INDIC0_MASK'                                                => 0x20,
     'INDIC1_MASK'                                                => 0x40,
     'INDIC2_MASK'                                                => 0x80,
@@ -141,6 +144,7 @@ our %scimsg_dummyhash = (
     'SCI_BRACEHIGHLIGHT'                                         => 2351,
     'SCI_BRACEHIGHLIGHTINDICATOR'                                => 2498,
     'SCI_BRACEMATCH'                                             => 2353,
+    'SCI_BRACEMATCHNEXT'                                         => 2369,
     'SCI_CALLTIPACTIVE'                                          => 2202,
     'SCI_CALLTIPCANCEL'                                          => 2201,
     'SCI_CALLTIPPOSSTART'                                        => 2203,
@@ -212,6 +216,15 @@ our %scimsg_dummyhash = (
     'SCI_ENDUNDOACTION'                                          => 2079,
     'SCI_ENSUREVISIBLE'                                          => 2232,
     'SCI_ENSUREVISIBLEENFORCEPOLICY'                             => 2234,
+    'SCI_EOLANNOTATIONCLEARALL'                                  => 2744,
+    'SCI_EOLANNOTATIONGETSTYLE'                                  => 2743,
+    'SCI_EOLANNOTATIONGETSTYLEOFFSET'                            => 2748,
+    'SCI_EOLANNOTATIONGETTEXT'                                   => 2741,
+    'SCI_EOLANNOTATIONGETVISIBLE'                                => 2746,
+    'SCI_EOLANNOTATIONSETSTYLE'                                  => 2742,
+    'SCI_EOLANNOTATIONSETSTYLEOFFSET'                            => 2747,
+    'SCI_EOLANNOTATIONSETTEXT'                                   => 2740,
+    'SCI_EOLANNOTATIONSETVISIBLE'                                => 2745,
     'SCI_EXPANDCHILDREN'                                         => 2239,
     'SCI_FINDCOLUMN'                                             => 2456,
     'SCI_FINDINDICATORFLASH'                                     => 2641,
@@ -237,6 +250,7 @@ our %scimsg_dummyhash = (
     'SCI_GETAUTOMATICFOLD'                                       => 2664,
     'SCI_GETBACKSPACEUNINDENTS'                                  => 2263,
     'SCI_GETBIDIRECTIONAL'                                       => 2708,
+    'SCI_GETBOOSTREGEXERRMSG'                                    => 5000,
     'SCI_GETBUFFEREDDRAW'                                        => 2034,
     'SCI_GETCARETFORE'                                           => 2138,
     'SCI_GETCARETLINEBACK'                                       => 2097,
@@ -329,6 +343,7 @@ our %scimsg_dummyhash = (
     'SCI_GETMOUSESELECTIONRECTANGULARSWITCH'                     => 2669,
     'SCI_GETMOUSEWHEELCAPTURES'                                  => 2697,
     'SCI_GETMOVEEXTENDSSELECTION'                                => 2706,
+    'SCI_GETMULTIEDGECOLUMN'                                     => 2749,
     'SCI_GETMULTIPASTE'                                          => 2615,
     'SCI_GETMULTIPLESELECTION'                                   => 2564,
     'SCI_GETNAMEDSTYLES'                                         => 4029,
@@ -365,7 +380,9 @@ our %scimsg_dummyhash = (
     'SCI_GETSELECTIONNCARET'                                     => 2577,
     'SCI_GETSELECTIONNCARETVIRTUALSPACE'                         => 2581,
     'SCI_GETSELECTIONNEND'                                       => 2587,
+    'SCI_GETSELECTIONNENDVIRTUALSPACE'                           => 2727,
     'SCI_GETSELECTIONNSTART'                                     => 2585,
+    'SCI_GETSELECTIONNSTARTVIRTUALSPACE'                         => 2726,
     'SCI_GETSELECTIONS'                                          => 2570,
     'SCI_GETSELECTIONSTART'                                      => 2143,
     'SCI_GETSELEOLFILLED'                                        => 2479,
@@ -381,10 +398,13 @@ our %scimsg_dummyhash = (
     'SCI_GETSUBSTYLESSTART'                                      => 4021,
     'SCI_GETTABDRAWMODE'                                         => 2698,
     'SCI_GETTABINDENTS'                                          => 2261,
+    'SCI_GETTABMINIMUMWIDTH'                                     => 2725,
     'SCI_GETTABWIDTH'                                            => 2121,
     'SCI_GETTAG'                                                 => 2616,
     'SCI_GETTARGETEND'                                           => 2193,
+    'SCI_GETTARGETENDVIRTUALSPACE'                               => 2731,
     'SCI_GETTARGETSTART'                                         => 2191,
+    'SCI_GETTARGETSTARTVIRTUALSPACE'                             => 2729,
     'SCI_GETTARGETTEXT'                                          => 2687,
     'SCI_GETTECHNOLOGY'                                          => 2631,
     'SCI_GETTEXT'                                                => 2182,
@@ -494,8 +514,10 @@ our %scimsg_dummyhash = (
     'SCI_MARKERDELETEHANDLE'                                     => 2018,
     'SCI_MARKERENABLEHIGHLIGHT'                                  => 2293,
     'SCI_MARKERGET'                                              => 2046,
+    'SCI_MARKERHANDLEFROMLINE'                                   => 2732,
     'SCI_MARKERLINEFROMHANDLE'                                   => 2017,
     'SCI_MARKERNEXT'                                             => 2047,
+    'SCI_MARKERNUMBERFROMLINE'                                   => 2733,
     'SCI_MARKERPREVIOUS'                                         => 2048,
     'SCI_MARKERSETALPHA'                                         => 2476,
     'SCI_MARKERSETBACK'                                          => 2042,
@@ -617,6 +639,7 @@ our %scimsg_dummyhash = (
     'SCI_SETIDENTIFIER'                                          => 2622,
     'SCI_SETIDENTIFIERS'                                         => 4024,
     'SCI_SETIDLESTYLING'                                         => 2692,
+    'SCI_SETILEXER'                                              => 4033,
     'SCI_SETIMEINTERACTION'                                      => 2679,
     'SCI_SETINDENT'                                              => 2122,
     'SCI_SETINDENTATIONGUIDES'                                   => 2132,
@@ -690,10 +713,13 @@ our %scimsg_dummyhash = (
     'SCI_SETSTYLINGEX'                                           => 2073,
     'SCI_SETTABDRAWMODE'                                         => 2699,
     'SCI_SETTABINDENTS'                                          => 2260,
+    'SCI_SETTABMINIMUMWIDTH'                                     => 2724,
     'SCI_SETTABWIDTH'                                            => 2036,
     'SCI_SETTARGETEND'                                           => 2192,
+    'SCI_SETTARGETENDVIRTUALSPACE'                               => 2730,
     'SCI_SETTARGETRANGE'                                         => 2686,
     'SCI_SETTARGETSTART'                                         => 2190,
+    'SCI_SETTARGETSTARTVIRTUALSPACE'                             => 2728,
     'SCI_SETTECHNOLOGY'                                          => 2630,
     'SCI_SETTEXT'                                                => 2181,
     'SCI_SETTWOPHASEDRAW'                                        => 2284,
@@ -1028,10 +1054,11 @@ our %scimsg_dummyhash = (
     'SC_MARK_VLINE'                                              => 9,
     'SC_MASK_FOLDERS'                                            => 0xFE000000,
     'SC_MAX_MARGIN'                                              => 4,
-    'SC_MODEVENTMASKALL'                                         => 0x3FFFFF,
+    'SC_MODEVENTMASKALL'                                         => 0x7FFFFF,
     'SC_MOD_BEFOREDELETE'                                        => 0x800,
     'SC_MOD_BEFOREINSERT'                                        => 0x400,
     'SC_MOD_CHANGEANNOTATION'                                    => 0x20000,
+    'SC_MOD_CHANGEEOLANNOTATION'                                 => 0x400000,
     'SC_MOD_CHANGEFOLD'                                          => 0x8,
     'SC_MOD_CHANGEINDICATOR'                                     => 0x4000,
     'SC_MOD_CHANGELINESTATE'                                     => 0x8000,
